@@ -187,10 +187,14 @@ def test_python_parser():
 def test_nbformat_parser():
 
     cells = parse_python(SIMPLE_CELL_WITH_OUTPUT)
-    cells_to_notebook(cells, path='tmp.ipynb')
-    code = notebook_to_code('tmp.ipynb', (lambda fmt, content: 'figure.png'))
+    cells_to_notebook(cells, path='tmp.ipynb', language='python')
+    language, code = notebook_to_code(
+        'tmp.ipynb',
+        (lambda fmt, content: 'figure.png')
+    )
     assert(code == SIMPLE_CELL_WITH_OUTPUT)
 
 
 if __name__ == '__main__':
     test_python_parser()
+    test_nbformat_parser()
